Module compression_io

Module compression_io 

Streaming compress/decompress, block I/O, AdaptiveCompressor, and factory.

Structs

AdaptiveCompressor
Adaptive compressor that automatically selects the best compression method

Functions

create_compressor
Create a boxed compressor from the given method description