pub fn create_compressor(
method: &CompressionMethod,
) -> Box<dyn VectorCompressor>Expand description
Create a boxed compressor from the given method description
pub fn create_compressor(
method: &CompressionMethod,
) -> Box<dyn VectorCompressor>Create a boxed compressor from the given method description