pub struct FlatIndex {
pub entries: Vec<VectorEntry>,
pub dims: usize,
}Expand description
A flat in-memory ANN index holding a collection of VectorEntry values.
All entries in the index must have the same dimensionality.
Fields
entries: Vec<VectorEntry>All stored entries.
dims: usizeDimensionality of the vectors stored in this index.
Implementations
Sourceimpl FlatIndex
impl FlatIndex
Sourcepub fn new(dims: usize) -> Self
pub fn new(dims: usize) -> Self
Create an empty flat index for vectors of the given dimensionality.
Sourcepub fn insert(&mut self, entry: VectorEntry) -> Result<(), MergeError>
pub fn insert(&mut self, entry: VectorEntry) -> Result<(), MergeError>
Insert an entry. Returns an error if the entry’s vector length does not match the index dimensionality.