Streaming compress/decompress, block I/O, AdaptiveCompressor, and factory.
Structs
- Adaptive
Compressor - Adaptive compressor that automatically selects the best compression method
Functions
- create_
compressor - Create a boxed compressor from the given method description