Index persistence with compression
This module provides serialization and deserialization of vector indices with support for compression, versioning, and incremental updates.
Re-exports
pub use snapshot::IndexSnapshot;pub use snapshot::SnapshotHeader;pub use point_in_time::CheckpointRef;pub use point_in_time::PointInTimeRestore;pub use restore::apply_wal_entry;pub use restore::restore_to_timestamp;pub use restore::RestoreReport;
Modules
- point_
in_ time - Point-in-time snapshot restore for vector indexes.
- restore
- Point-in-time restore for a
VectorStore. - snapshot
- HNSW Index Snapshot - Save and Restore without rebuilding
Structs
- Incremental
Persistence - Incremental persistence manager
- Persistence
Config - Persistence configuration
- Persistence
Manager - Persistence manager for HNSW indices
Enums
- Compression
Algorithm - Compression algorithm for index persistence