Index persistence with compression
This module provides serialization and deserialization of vector indices with support for compression, versioning, and incremental updates.
Re-exports
pub use snapshot::IndexSnapshot;pub use snapshot::SnapshotHeader;
Modules
- snapshot
- HNSW Index Snapshot - Save and Restore without rebuilding
Structs
- Incremental
Persistence - Incremental persistence manager
- Persistence
Config - Persistence configuration
- Persistence
Manager - Persistence manager for HNSW indices
Enums
- Compression
Algorithm - Compression algorithm for index persistence