Module real_time_analytics

Module real_time_analytics 

Real-time analytics and monitoring for vector search operations

This module provides comprehensive monitoring, analytics, and performance insights for vector search systems including dashboards, alerts, and benchmarking.

Structs

Alert
Alert information
AlertConfig
Alert configuration
AlertManager
Alert management system
AlertRule
Alert rule definition
AnalyticsConfig
Configuration for analytics engine
AnalyticsReport
Analytics report structure
CustomMetric
Custom metrics defined by users
DashboardData
Dashboard data aggregation
EmailNotificationChannel
Email notification channel
GrowthMetrics
Growth metrics
MetricsCollector
Comprehensive metrics collection
NetworkIO
Network I/O metrics
OverviewData
Overview dashboard data
PerformanceMonitor
Performance monitoring with alerting
PerformanceProfiler
Performance profiler for detailed analysis
PerformanceThresholds
Performance thresholds for alerting
PopularQuery
Popular query tracking
ProfileData
QualityMetrics
Vector search quality metrics
QualityMetricsData
Quality metrics dashboard data
QueryAnalyzer
Query pattern analysis
QueryMetrics
Query performance metrics
QueryPattern
Query pattern information
QueryPerformanceData
Query performance dashboard data
SlackNotificationChannel
Slack notification channel
SmtpConfig
SystemHealthData
System health dashboard data
SystemInfo
System information structure
SystemMetrics
System resource metrics
UsageAnalyticsData
Usage analytics dashboard data
UsageTrends
Usage trends analysis
VectorAnalyticsEngine
Real-time analytics engine for vector operations
WebhookNotificationChannel
Webhook notification channel

Enums

AlertSeverity
Alert severity levels
AlertType
Alert types for performance monitoring
AnalyticsEvent
Analytics event types
ExportFormat
Export formats for metrics

Traits

NotificationChannel
Notification channel trait